@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
+# $Id: __init__.py 9965 2017-05-13 03:21:53Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-04 18:37:30 +0800 (Thu, 04 May 2017) $
-# $Revision: 9947 $
+# $Date: 2017-05-13 11:21:53 +0800 (Sat, 13 May 2017) $
+# $Revision: 9965 $
 
 import os
 import sys
@@ -303,7 +303,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         ALLOWED_HOSTS = ['127.0.0.1', 'localhost']
         
     if settingsDict.get('ALLOWED_DOMAINS', None):
-        ALLOWED_HOSTS += list(settingsDict['ALLOWED_DOMAINS'])
+        ALLOWED_HOSTS += settingsDict['ALLOWED_DOMAINS']
     else:
         if settingsDict['SERVER_MODE'] != DEVELOPMENT:
             if warns:
@@ -491,7 +491,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     #=========================================================================
     # I18n.
     i18nDefaults = {
-        # On Unix systems, a value of None will cause Django to use the same
+        # On Linux systems, a value of None will cause Django to use the same
         # timezone as the operating system.
         # If running in a Windows environment this must be set to the same as 
         # your system time zone.
